@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-651c853375b2b38ef3e2acc3ecfab514
-key: yesod_7JyMmmNGKgfAe16YcyIQEw
+id: yesod-1.4.2-df6969dfbc858b998ec244264fecd72a
+key: yesod_9LWeoghHzSt4CfVNvX2NMq
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-7JyMmmNGKgfAe16YcyIQEw
+hs-libraries: HSyesod-1.4.2-9LWeoghHzSt4CfVNvX2NMq
 depends:
     aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -43,15 +43,15 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
-    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
-    wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.3-b193a405602f21fe67837dcb996939ee
+    wai-3.2.0-e103f0650175c07d97df46c35b6789e8
+    wai-extra-3.0.14.1-0c42224b2d6876be23597f0341613f03
+    wai-logger-2.2.4.1-174bc5cb20d0c648b67c086b95df789c
+    warp-3.2.3-65ec311029bca8d40c69f107435d220d
     yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
-    yesod-auth-1.4.12-7be9649dc74d6f1258f9690098986b59
-    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
-    yesod-form-1.4.6-e87deb06856da3fa0104c0eca2c57620
-    yesod-persistent-1.4.0.3-ca84b6eb145e15f51b714d496323d807
+    yesod-auth-1.4.12-4e64c62214b64b9f61de4b7b73723e55
+    yesod-core-1.4.19-76e562217b8c2dec9e581394dccca7d9
+    yesod-form-1.4.6-d7657a7d5538a6119e62f62c50053d42
+    yesod-persistent-1.4.0.3-be43da91bd3f8b1a5afded36ccce5fee
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
